@@ -212,6 +212,7 @@ class XRSTimeSeries(GenericTimeSeries):
                 raise ValueError("Date not recognized")
             xrsb = hdulist[2].data['FLUX'][0][:, 0]
             xrsa = hdulist[2].data['FLUX'][0][:, 1]
+            # TODO how to extract quality flags from HDU?
             seconds_from_start = hdulist[2].data['TIME'][0]
         elif 1 <= len(hdulist) <= 3:
             start_time = parse_time(header['TIMEZERO'], format='utime')
@@ -257,6 +258,8 @@ class XRSTimeSeries(GenericTimeSeries):
             if "a_flux" in d.variables:
                 xrsa = np.array(d["a_flux"])
                 xrsb = np.array(d["b_flux"])
+                xrsa_quality = np.array(d['a_flags'])
+                xrsb_quality = np.array(d['b_flags'])
 
                 start_time_str = d["time"].attrs["units"]
                 if not isinstance(start_time_str, str):
@@ -268,6 +271,9 @@ class XRSTimeSeries(GenericTimeSeries):
             elif "xrsa_flux" in d.variables:
                 xrsa = np.array(d["xrsa_flux"])
                 xrsb = np.array(d["xrsb_flux"])
+                xrsa_quality = np.array(d['xrsa_flags'])
+                xrsb_quality = np.array(d['xrsb_flags'])
+
                 start_time_str = d["time"].attrs["units"]
                 if not isinstance(start_time_str, str):
                     # For h5netcdf<0.14
@@ -279,10 +285,13 @@ class XRSTimeSeries(GenericTimeSeries):
             else:
                 raise ValueError(f"The file {filepath} doesn't seem to be a GOES netcdf file.")
 
-        data = DataFrame({"xrsa": xrsa, "xrsb": xrsb}, index=times.datetime)
+        data = DataFrame({"xrsa": xrsa, "xrsb": xrsb, "xrsa_quality": xrsa_quality,
+                         "xrsb_quality": xrsb_quality}, index=times.datetime)
         data = data.replace(-9999, np.nan)
         units = OrderedDict([("xrsa", u.W/u.m**2),
-                             ("xrsb", u.W/u.m**2)])
+                             ("xrsb", u.W/u.m**2),
+                             ("xrsa_quality", int),
+                             ("xrsb_quality", int)])
 
         return data, header, units
 
